@@ -148,6 +148,22 @@ def change_info():
         return wrapper
     return decorator
 
+def can_delete():
+    def decorator(func):
+        @functools.wraps(func)
+        async def wrapper(event):
+            sed = await utilsbot.get_permissions(event.chat_id, event.sender_id)
+            user = event.sender_id
+            if sed.delete_messages:
+                await func(event)
+            if not user:
+                pass
+            if not sed.delete_messages:
+                await event.reply("You Dont Have Permissions to Delete Messages")
+            if not sed.is_admin:
+                await event.reply("Only Admins Can Use it.")
+        return wrapper
+    return decorator
 
 def is_bot_admin():
     def decorator(func):
@@ -196,5 +212,6 @@ can_pin = can_pin()
 chat_creator = chat_creator()
 can_promote = can_promote()
 change_info = change_info()
+can_delete = can_delete()
 
 # =================== CONSTANT ===================
